using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using UnityEditor;
using UnityEngine;
using UnityEditor.Build;
using UnityEditor.Build.Reporting;
using LitJson;

public class HMSBuildProcessor : IPostprocessBuildWithReport
{
    public int callbackOrder
    {
        get { return 10; }
    }

    private Dictionary<string, string> dependencyMap = new Dictionary<string, string>();

    /**
    * build 构建完成后回调
    */
    public void OnPostprocessBuild(BuildReport report)
    {
        if (report.summary.platform == BuildTarget.OpenHarmony)
        {
            //修改文件
            DefaultRecodeFile(report.summary.outputPath);
            CustomRecodeFile(report.summary.outputPath);
        }
    }

    /**
     * 默认需要修改的文件
     */
    private void DefaultRecodeFile(string path)
    {
        ModifyBuildProfile(path);
    }

    /**
     * build-profile.json5 配置项修改
     */
    private void ModifyBuildProfile(string path)
    {
        FileOperator foBuildProfile = new FileOperator(path + "/build-profile.json5");
        //移除原有配置项
        //foBuildProfile.ReplaceString(" \"compileSdkVersion\": 12,", "");
        //foBuildProfile.ReplaceString(" \"compatibleSdkVersion\": 12", "");
        //foBuildProfile.ReplaceString(" \"compileSdkVersion\": 11,", "");
        //foBuildProfile.ReplaceString(" \"compatibleSdkVersion\": 11", "");
        //添加正确配置项
        string buildProfileDefaultContent = "\"signingConfig\": \"default\"";
        StringBuilder buildProfileNewContent = new StringBuilder("        " + buildProfileDefaultContent);
        buildProfileNewContent.Append(",");
        buildProfileNewContent.Append("\n");
        //buildProfileNewContent.Append("        \"compatibleSdkVersion\": \"5.0.0(12)\",");
        //buildProfileNewContent.Append("\n");
        //buildProfileNewContent.Append("        \"runtimeOS\": \"HarmonyOS\",");
        //buildProfileNewContent.Append("\n");
        buildProfileNewContent.Append("        \"buildOption\":  {\n          \"strictMode\": {\n            \"useNormalizedOHMUrl\": true\n          }\n        },");
        foBuildProfile.ReplaceString(buildProfileDefaultContent, buildProfileNewContent.ToString());
    }



    private void CustomRecodeFile(string path)
    {
        // 移动ghomesdk
        string oldPath = path + "/entry/libs/arm64-v8a/ghomesdk.har";
        //string newPath = path + "/entry/libs/ghomesdk.har";
        //FileOperator.MoveFile(oldPath, newPath);

        ModifyMainWorker(path);
        //ModifyAbilityIndex(path);
        //dependencyMap.Add("ghomesdk", "file:./libs/ghomesdk.har");
        //AddDependencies(path);
    }

        /**
     * TuanjieMainWorker.cs 新增import和消息监听代码
     */
    private void ModifyAbilityIndex(string path)
    {
        string filePath = path + "/entry/src/main/ets/pages/TuanjiePlayerAbilityIndex.ets";
        if (!File.Exists(filePath)) return;
        FileOperator foOhPackage = new FileOperator(filePath);

       // 增加import内容
        //string[] importLines1 = { "import { GHome } from 'ghomesdk'", "import { GHomeApiManager } from '../GHomeApiManager'" };
        //foOhPackage.InsertImports(importLines1);

        //string[] insertContent1 = { "    SetToGlobalThis('gHomeSDKOperation', GHome.getInstance())", "    SetToGlobalThis('gHomeSDKManager', GHomeApiManager)" };
        // 找到内容插入的位置
        //string afterFunction = "SetToGlobalThis(DebuggerDialogInfo.DebuggerDialogInfoKey, this.debuggerDialogInfo);";
        //foOhPackage.InsertAfterLineContent(afterFunction, insertContent1);

        // File.WriteAllLines(filePath, codesNew);
    }

    /**
     * TuanjieMainWorker.cs 新增import和消息监听代码
     */
    private void ModifyMainWorker(string path)
    {
        string filePath = path + "/entry/src/main/ets/workers/TuanjieMainWorker.ets";
        if (!File.Exists(filePath)) return;
        FileOperator foOhPackage = new FileOperator(filePath);

        // 增加import内容
        string[] importLines1 = { "import { GHome } from 'ghomesdk'", "import { GHomeApiManager } from '../GHomeApiManager'" };
        foOhPackage.InsertImports(importLines1);

        string[] initMessageBindContent = { "      GHomeApiManager.registerGHomeApi(msg)" };
        // 找到内容插入的位置
        string afterFunction = "this.threadWorker.onmessage = (msg)";
        foOhPackage.InsertAfterLineContent(afterFunction, initMessageBindContent);
    }

    private int CountSymbolInLine(char symbol, string lineContent)
    {
        IEnumerable<char> stringQuery =
            from ch in lineContent
            where ch.Equals(symbol)
            select ch;
        return stringQuery.Count();
    }

    private void AddDependencies(string path)
    {
        if (dependencyMap.Count == 0)
        {
            return;
        }

        FileOperator foOhPackage = new FileOperator(path + "/entry/oh-package.json5");
        StringBuilder replaceString = new StringBuilder("\"dependencies\": {");
        foreach (var dependency in dependencyMap)
        {
            replaceString.Append("\n");
            replaceString.Append("  \"" + dependency.Key + "\": \"" + dependency.Value + "\"");
        }

        replaceString.Append("\n");
        replaceString.Append("}");
        foOhPackage.ReplaceString("\"dependencies\": {}", replaceString.ToString());
    }
}