﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using Newtonsoft.Json;

using Debug = GInterSDK.GDebug;
using System;

public class GHomeInterfaceCallback : MonoBehaviour
{
    public delegate void GHomeCallback(long code, string msg, Dictionary<string, object> data);

    public static GHomeCallback initCallback;
    public static GHomeCallback loginCallback;
    public static GHomeCallback logoutCallback;
    public static GHomeCallback payCallback;
    public static GHomeCallback exitCallback;
    public static GHomeCallback switchAccountCallback;
    public static GHomeCallback doExtendCallback;
    public static GHomeCallback getAreaCallback;
    public static GHomeCallback bindCallback;
    public static GHomeCallback unregisterCallback;
    public static GHomeCallback getProductsInfoCallback;
    public static GHomeCallback querySupplementCallback;

    public static GHomeCallback querySupCallback;

    public static GHomeCallback getTicketCallback;

    public static GHomeCallback shareCallback;
    public static GHomeCallback recordCallback;

    public static GHomeCallback ifNeedShowUserAgreementCallback;
    public static GHomeCallback getUserAgreementCallback;
    public static GHomeCallback getUserAgreementContentCallback;
    public static GHomeCallback showUserAgreementCallback;
    public static GHomeCallback scanQRCallback;

    public static GHomeCallback filterSensitiveWordCallback;



    public static GHomeCallback screenshotCallback;


    public static void InitCallback(string data)
    {
        ParseResult("init", data);
    }

    public static void LoginCallback(string data)
    {
        ParseResult("login", data);
    }

    public static void LogoutCallback(string data)
    {
        ParseResult("logout", data);
    }

    public static void PayCallback(string data)
    {
        ParseResult("pay", data);
    }

    public static void BindCallback(string data)
    {
        ParseResult("bind", data);
    }

    public static void UnregisterCallback(string data)
    {
        ParseResult("unregister", data);
    }

    public static void QuerySupOrderCallback(string data)
    {
        ParseResult("querySupOrder", data);
    }

    public static void GetAreaConfigCallback(string data)
    {
        ParseResult("getAreaConfig", data);
    }


    public static void GetTicketCallback(string data)
    {
        ParseResult("getTicket", data);
    }

    public static void GetConfigProductsListCallback(string data)
    {
        ParseResult("getConfigProductsList", data);
    }

    public static void GetGoogleProductListWithIdsCalblack(string data)
    {
        ParseResult("getGoogleProductListWithIds", data);
    }

    public static void ShareCallback(string data)
    {
        ParseResult("share", data);
    }

    public static void RecordCallback(string data)
    {
        ParseResult("record", data);
    }

    public static void ScreenshotCallback(string data)
    {
        ParseResult("screenshot", data);
    }


    public static void IfNeedShowUserAgreementCallback(string data)
    {
        ParseResult("ifNeedShowUserAgreement", data);
    }

    public static void FilterSensitiveWordsCallback(string data)
    {
        ParseResult("filterSensitiveWords", data);
    }

    public static void GetUserAgreementCallback(string data)
    {
        ParseResult("getUserAgreement", data);
    }

    public static void GetUserAgreementContentCallback(string data)
    {
        ParseResult("getUserAgreementContent", data);
    }

    public static void ShowUserAgreementCallback(string data)
    {
        ParseResult("showUserAgreement", data);
    }

    public static void ScanQRCodeCallback(string data)
    {
        ParseResult("scanQR", data);
    }

    public static void SwitchAccountCallback(string data)
    {
        ParseResult("switchAccount", data);
    }

    public static void DoExtendCallback(string data)
    {
        ParseResult("doExtend", data);
    }


    private static void ParseResult(string type, string data)
    {
        Debug.Log("GHomeInterfaceCallback " + type + "callback, data:" + data);
        Dictionary<string, object> resultData = JsonConvert.DeserializeObject<Dictionary<string, object>>(data);
        Debug.Log("GHomeInterfaceCallback type: " + type + ",resultData.count: " + resultData.Count);

#if UNITY_ANDROID
        long code = (long)resultData["returnCode"];
        string msg = (string)resultData["returnMessage"];
#elif UNITY_IOS || UNITY_IPHONE
        long code = i(long)resultData["returnCode"];
        string msg = (string)resultData["returnMessage"];
#elif UNITY_OPENHARMONY
        long code = (long)resultData["retCode"];
        string msg = (string)resultData["retMsg"];
#endif
        switch (type)
        {
            case "init":
                initCallback(code, msg, resultData);
                break;
            case "login":
                loginCallback(code, msg, resultData);
                break;
            case "logout":
                logoutCallback(code, msg, resultData);
                break;
            case "pay":
                payCallback(code, msg, resultData);
                break;
            case "getAreaConfig":
                getAreaCallback(code, msg, resultData);
                break;
            case "getProductsWithIds":
                getProductsInfoCallback(code, msg, resultData);
                break;
            case "getGoogleProductListWithIds":
                getProductsInfoCallback(code, msg, resultData);
                break;
            case "getConfigProductsList":
                getProductsInfoCallback(code, msg, resultData);
                break;
            case "bind":
                bindCallback(code, msg, resultData);
                break;
            case "getTicket":
                getTicketCallback(code, msg, resultData);
                break;
            case "unregister":
                unregisterCallback(code, msg, resultData);
                break;
            case "share":
#if UNITY_ANDROID
                resultData.Add("userData", "");
#else
#endif
                shareCallback(code, msg, resultData);
                break;
            case "screenshot":
                screenshotCallback(code, msg, resultData);
                break;
            case "ifNeedShowUserAgreement":
                ifNeedShowUserAgreementCallback(code, msg, resultData);
                break;
            case "getUserAgreement":
                getUserAgreementCallback(code, msg, resultData);
                break;

            case "getUserAgreementContent":
                getUserAgreementContentCallback(code, msg, resultData);
                break;

            case "showUserAgreement":
                showUserAgreementCallback(code, msg, resultData);
                break;
            case "scanQR":
                scanQRCallback(code, msg, resultData);
                break;
            case "record":
                recordCallback(code, msg, resultData);
                break;
            case "filterSensitiveWords":
                filterSensitiveWordCallback(code, msg, resultData);
                break;
            case "switchAccount":
                switchAccountCallback(code, msg, resultData);
                break;

            case "doExtend":
                doExtendCallback(code, msg, resultData);
                break;

        }
    }

}


