﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Xml;
using UnityEditor;
using UnityEngine;

using Debug = GInterSDK.GDebug;


#if UNITY_EDITOR
[CustomEditor(typeof(AndroidConfig))]
public class AndroidConfigInspector : Editor
{

    //packageName android
    public SerializedProperty packageName;

    public SerializedProperty tencentAppid;

    private void OnEnable()
    {
        packageName = serializedObject.FindProperty("packageName");

        tencentAppid = serializedObject.FindProperty("tencentAppid");
    }

    public override void OnInspectorGUI()
    {
        serializedObject.Update();

        EditorGUI.indentLevel = 1;

        EditorGUILayout.PropertyField(packageName, new GUIContent("安卓包名"));
        GUILayout.Space(5);

        EditorGUILayout.PropertyField(tencentAppid, new GUIContent("腾讯后台登记的AppId"));
        GUILayout.Space(5);

        GUILayout.Space(10);


        // 打印数据
        if (GUILayout.Button("保存"))
        {
            Debug.Log("XTT Meta-data saved!!");

            SaveDatas();
        }

        if (GUI.changed)
        {
            EditorUtility.SetDirty(target);
        }

        //Debug.Log("XTT ApplyModifiedProperties!!");
        serializedObject.ApplyModifiedProperties();

    }

    void UpdateActivityData(string pathManifest, string activityName, string childNodeName, XmlDocument xmlD)
    {
        Debug.Log("XTT ActivityName: " + activityName + "find begin1111");
        foreach (XmlNode sdf in xmlD.GetElementsByTagName("activity"))
        {
            if (sdf.HasChildNodes)
            {
                if (sdf.Attributes[0].Value == activityName)
                {
                    Debug.Log("XTT ActivityName: " + activityName + "find success");
                    if (sdf.FirstChild.HasChildNodes)
                    {
                        foreach (XmlNode chiSdf in sdf.FirstChild.ChildNodes)
                        {
                            if (chiSdf.Name == childNodeName)
                            {
                                chiSdf.Attributes[0].Value = "tencent" + tencentAppid.stringValue;
                            }
                            Debug.Log("XTT " + activityName + "changed");
                        }
                    }
                }

            }
        }

        //------------ add node end ------------

        Debug.Log("XTT out AndroidManifest saved!!     xmlD.Save(pathManifest)");
        xmlD.Save(pathManifest);
    }

    //void UpdateActivityAlias(XmlDocument xmlD)
    //{
    //    Debug.Log("XTT UpdateActivityAlias start");
    //    foreach (XmlNode appNode in xmlD.GetElementsByTagName("application"))
    //    {
    //        XmlNode nodeWXPay = xmlD.CreateElement("activity-alias");
    //        nodeWXPay.Attributes.Append(CreateAttribute(nodeWXPay, "android:name", "${applicationId}.wxapi.WXPayEntryActivity"));
    //        nodeWXPay.Attributes.Append(CreateAttribute(nodeWXPay, "android:exported", "true"));
    //        nodeWXPay.Attributes.Append(CreateAttribute(nodeWXPay, "android:targetActivity", "com.ghome.sdk.common.GHomeWXPayActivity"));

    //        XmlNode nodeWXEntry = xmlD.CreateElement("activity-alias");
    //        nodeWXEntry.Attributes.Append(CreateAttribute(nodeWXEntry, "android:name", "${applicationId}.wxapi.WXEntryActivity"));
    //        nodeWXEntry.Attributes.Append(CreateAttribute(nodeWXEntry, "android:exported", "true"));
    //        nodeWXEntry.Attributes.Append(CreateAttribute(nodeWXEntry, "android:targetActivity", "com.ghome.sdk.common.GHomeWXEntryActivity"));

    //        XmlNode nodeDYEntry = xmlD.CreateElement("activity-alias");
    //        nodeDYEntry.Attributes.Append(CreateAttribute(nodeDYEntry, "android:name", "${applicationId}.dyapi.DYEntryActivity"));
    //        nodeDYEntry.Attributes.Append(CreateAttribute(nodeDYEntry, "android:exported", "true"));
    //        nodeDYEntry.Attributes.Append(CreateAttribute(nodeDYEntry, "android:targetActivity", "com.ghome.sdk.common.DaoYuHandlerActivity"));

    //        appNode.AppendChild(nodeWXPay);
    //        appNode.AppendChild(nodeWXEntry);
    //        appNode.AppendChild(nodeDYEntry);

    //        Debug.Log("XTT UpdateActivityAlias end 000");
    //        break;
    //    }
    //    Debug.Log("XTT UpdateActivityAlias 111");
    //}

    //XmlAttribute CreateAttribute(XmlNode node, string attributeName, string value)
    //{
    //    try
    //    {
    //        XmlDocument doc = node.OwnerDocument;
    //        XmlAttribute attr = null;
    //        attr = doc.CreateAttribute(attributeName);
    //        attr.Value = value;
    //        node.Attributes.SetNamedItem(attr);
    //        return attr;
    //    }
    //    catch (Exception err)
    //    {
    //        string desc = err.Message;
    //        return null;
    //    }
    //}

    void UpdateData(string pathManifest, string dataHost, string schemeStr, XmlDocument xmlD)
    {
        //------------ add node start ------------

        foreach (XmlNode sdf in xmlD.GetElementsByTagName("data"))
        {
            if (sdf.Attributes.Count > 1)
            {
                if (sdf.Attributes[0].Value == dataHost)
                {
                    sdf.Attributes[1].Value = schemeStr;
                    Debug.Log("XTT" + dataHost + "changed");
                }
            }
        }

        //------------ add node end ------------

        Debug.Log("XTT out AndroidManifest saved!!     xmlD.Save(pathManifest)");
        xmlD.Save(pathManifest);
    }

    void SaveDatas()
    {
        var pathManifest = Application.dataPath + "/Plugins/Android/AndroidManifest.xml";
        XmlDocument xmlD = new XmlDocument();
        xmlD.Load(pathManifest);

        UpdateData(pathManifest, "home", "ks_ghome_" + packageName.stringValue.Replace(".", ""), xmlD);

        UpdateActivityData(pathManifest, "com.tencent.tauth.AuthActivity", "data", xmlD);

    }
}

#endif
